/**
 * Legato is a configurable, lightweight web mapping client that can be
 * easily embedded into web pages and portals, CMS and individual web
 * applications. Legato is implemented in JavaScript and based on the
 * popular open source library OpenLayers.
 *
 * Copyright (C) 2010  disy Informationssysteme GmbH, http://www.disy.net
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package net.disy.legato.tools.jts;

import java.text.MessageFormat;

import org.directwebremoting.extend.MarshallException;

import com.vividsolutions.jts.geom.Coordinate;
import com.vividsolutions.jts.geom.LineString;
import com.vividsolutions.jts.geom.Point;

public class LineStringConverter extends AbstractGeometryConverter<LineString, double[][]> {

  private PointConverter pointConverter = new PointConverter();
  
  @Override
  protected String getGeometryType() {
    return "LineString";
  }

  @Override
  protected Class<double[][]> getCoordinatesType() {
    return double[][].class;
  }

  @Override
  protected double[][] createCoordinates(LineString lineString) throws MarshallException {

    if (lineString == null) {
      return null;
    }
    else if (lineString.isEmpty()) {
      return new double[0][0];
    }
    else {
      int numberOfPoints = lineString.getNumPoints();
      double[][] coordinates = new double[numberOfPoints][];
      for (int index = 0; index < numberOfPoints; index++) {
        coordinates[index] = pointConverter.createCoordinates(lineString.getPointN(index));
      }
      return coordinates;
    }
  }

  @Override
  protected LineString createGeometry(double[][] coordinates) throws MarshallException {

    if (coordinates == null) {
      return null;
    }
    else if (coordinates.length >= 2) {
      Coordinate[] coordinateArray = new Coordinate[coordinates.length];
      for (int index = 0; index < coordinates.length; index++) {
        coordinateArray[index] = pointConverter.createGeometry(coordinates[index]).getCoordinate();
      }
      return getGeometryFactory().createLineString(coordinateArray);
    }
    else {
      throw new MarshallException(Point.class, MessageFormat.format(
          "Incorrect number of coordinate components [{0}].", //$NON-NLS-1$
          coordinates.length));
    }
  }

}
