/**
 * Legato is a configurable, lightweight web mapping client that can be
 * easily embedded into web pages and portals, CMS and individual web
 * applications. Legato is implemented in JavaScript and based on the
 * popular open source library OpenLayers.
 *
 * Copyright (C) 2010  disy Informationssysteme GmbH, http://www.disy.net
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package net.disy.legato.tools.util;

import java.io.IOException;
import java.io.InputStream;
import java.text.MessageFormat;
import java.util.ArrayList;
import java.util.List;

import org.apache.commons.io.IOUtils;

public class DefaultResourceResolver implements IResourceResolver {

  private ClassLoader classLoader = getClass().getClassLoader();

  protected ClassLoader getClassLoader() {
    return classLoader;
  }

  @Override
  public List<String> resolve(String packageResourceName, String resourceName) throws IOException {

    final String scriptsResourceName = resourceName.startsWith("/")
        ? resourceName
        : packageResourceName + "/" + resourceName;

    InputStream is = null;
    try {
      is = getClassLoader().getResourceAsStream(scriptsResourceName);
      if (is == null) {
        throw new IOException(MessageFormat.format(
            "Could not load scripts resource [{0}].",
            scriptsResourceName));
      }
      @SuppressWarnings("unchecked")
      final List<String> scriptResourceNames = IOUtils.readLines(is);
      final List<String> results = new ArrayList<String>();
      for (final String name : scriptResourceNames) {
        results.add(name);
      }
      return results;
    }
    finally {
      IOUtils.closeQuietly(is);
    }
  }
}
