/**
 * Legato is a configurable, lightweight web mapping client that can be
 * easily embedded into web pages and portals, CMS and individual web
 * applications. Legato is implemented in JavaScript and based on the
 * popular open source library OpenLayers.
 *
 * Copyright (C) 2010  disy Informationssysteme GmbH, http://www.disy.net
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package net.disy.legato.tools.util;

import java.util.ArrayList;
import java.util.List;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

import org.apache.commons.collections15.CollectionUtils;
import org.apache.commons.collections15.Predicate;
import org.apache.commons.collections15.Transformer;
import org.apache.commons.lang.StringUtils;

public class MainScriptListTransformer implements IListTransformer {

	private String prefix = StringUtils.EMPTY;

	public static final Pattern SCRIPTS_EXTRACT_PATTERN = Pattern
			.compile("(.*')([a-zA-Z0-9/]*\\.js)('.*)"); //$NON-NLS-1$

	@Override
	public List<String> transform(final List<String> resource) {
		List<String> copy = new ArrayList<String>(resource);

		CollectionUtils.filter(copy, new Predicate<String>() {
			public boolean evaluate(String object) {
				return SCRIPTS_EXTRACT_PATTERN.matcher((String) object)
						.matches();
			}
		});

		CollectionUtils.transform(copy, new Transformer<String, String>() {
			public String transform(String input) {
				Matcher matcher = SCRIPTS_EXTRACT_PATTERN
						.matcher((String) input);
				if (matcher.matches()) {
					String transformed = StringUtils.isEmpty(getPrefix()) ? StringUtils.EMPTY
							: "/" + getPrefix();

					return new StringBuilder(transformed).append("/") //$NON-NLS-1$
							.append(matcher.group(2)).toString();
				}
				return null;
			}
		});

		return copy;
	}

	public void setPrefix(String prefix) {
		this.prefix = prefix;
	}

	public String getPrefix() {
		return prefix;
	}

}
